@@ -38,7 +38,7 @@ from ae.gui_app import id_of_flow                           # type: ignore
 from ae.kivy_app import FlowPopup                           # type: ignore
 
 
-__version__ = '0.1.4'
+__version__ = '0.1.7'
 
 
 KEY_VAL_SEPARATOR = ": "
@@ -47,14 +47,18 @@ KEY_VAL_SEPARATOR = ": "
 Builder.load_string('''#: set KEY_VAL_SEPARATOR "''' + KEY_VAL_SEPARATOR + '''"
 
 <IterableDisplayerPopup>
-    child_data_maps: self.compile_data_maps(self.data)
-    size_hint_y: None
-    # minimum_height is to small:: height: self.ids.container.minimum_height
-    height: min(self.title_size * 3 + sum(chi.height for chi in self.ids.container.children), Window.height - sp(69))
+    optimal_content_height: content_box.minimum_height
+    IterableDisplayerContent:
+        id: content_box
+        child_data_maps: root.compile_data_maps(root.data)
+        size_hint_y: None
+        height: root.optimal_content_height
+
+<IterableDisplayerContent@DynamicChildrenBehavior+BoxLayout>
 
 <IterableDisplayerLabel@ScrollView>
     size_hint: 1, None
-    height: int(app.app_states['font_size'] * 1.5)
+    height: app.button_height
     text: "." + KEY_VAL_SEPARATOR + "."
     do_scroll_y: False
     BoxLayout:
@@ -77,7 +81,7 @@ Builder.load_string('''#: set KEY_VAL_SEPARATOR "''' + KEY_VAL_SEPARATOR + '''"
 
 <IterableDisplayerButton@BoxLayout>
     size_hint: 1, None
-    height: int(app.app_states['font_size'] * 1.5)
+    height: app.button_height
     text: "-" + KEY_VAL_SEPARATOR + "-"
     tap_flow_id: ""
     tap_kwargs: {}
@@ -120,13 +124,13 @@ class IterableDisplayerPopup(FlowPopup):
 
         cdm = list()
         for key, val in items:
-            text = str(key) + KEY_VAL_SEPARATOR + str(val)
+            text = (str(key) + KEY_VAL_SEPARATOR + str(val))[:369]  # cut long text preventing black texture kivy/gl bug
             if key in ('transferred_bytes', 'total_bytes') and val > 1024:
                 text += " (" + file_transfer_progress(val) + ")"
             kwargs: Dict[str, Any] = dict(text=text)
             if isinstance(val, (dict, list, tuple)):
                 cls = 'IterableDisplayerButton'
-                kwargs['tap_flow_id'] = id_of_flow('open', 'iterable_displayer', 'iterable sub item info')
+                kwargs['tap_flow_id'] = id_of_flow('open', 'iterable_displayer', text)
                 kwargs['tap_kwargs'] = dict(popup_kwargs=dict(title=text, data=val))
             else:
                 cls = 'IterableDisplayerLabel'
